@@ -7,9 +7,9 @@ import vtk.*;
 public class vtkOpenGLRenderer extends vtkRenderer
 {
 
-  private native String GetClassName_0();
-  public String GetClassName()
-    { return GetClassName_0(); }
+  private native int IsTypeOf_0(String id0);
+  public int IsTypeOf(String id0)
+    { return IsTypeOf_0(id0); }
 
   private native int IsA_1(String id0);
   public int IsA(String id0)
@@ -19,13 +19,13 @@ public class vtkOpenGLRenderer extends vtkRenderer
   public void DeviceRender()
     { DeviceRender_2(); }
 
-  private native void DeviceRenderTranslucentPolygonalGeometry_3();
-  public void DeviceRenderTranslucentPolygonalGeometry()
-    { DeviceRenderTranslucentPolygonalGeometry_3(); }
+  private native void DeviceRenderOpaqueGeometry_3();
+  public void DeviceRenderOpaqueGeometry()
+    { DeviceRenderOpaqueGeometry_3(); }
 
-  private native void ClearLights_4();
-  public void ClearLights()
-    { ClearLights_4(); }
+  private native void DeviceRenderTranslucentPolygonalGeometry_4();
+  public void DeviceRenderTranslucentPolygonalGeometry()
+    { DeviceRenderTranslucentPolygonalGeometry_4(); }
 
   private native void Clear_5();
   public void Clear()
@@ -39,17 +39,13 @@ public class vtkOpenGLRenderer extends vtkRenderer
   public int GetDepthPeelingHigherLayer()
     { return GetDepthPeelingHigherLayer_7(); }
 
-  private native void SetPass_8(vtkRenderPass id0);
-  public void SetPass(vtkRenderPass id0)
-    { SetPass_8(id0); }
+  private native boolean HaveApplePrimitiveIdBug_8();
+  public boolean HaveApplePrimitiveIdBug()
+    { return HaveApplePrimitiveIdBug_8(); }
 
-  private native long GetPass_9();
-  public vtkRenderPass GetPass() {
-    long temp = GetPass_9();
-
-    if (temp == 0) return null;
-    return (vtkRenderPass)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+  private native boolean IsDualDepthPeelingSupported_9();
+  public boolean IsDualDepthPeelingSupported()
+    { return IsDualDepthPeelingSupported_9(); }
 
   public vtkOpenGLRenderer() { super(); }
 
